@@ -1,11 +1,7 @@
 # templatetags/blog_utils.py
 from django import template
 from django.utils.safestring import mark_safe
-
-try:
-    from bs4 import BeautifulSoup
-except ImportError:
-    BeautifulSoup = None
+from bs4 import BeautifulSoup
 
 register = template.Library()
 
@@ -32,3 +28,22 @@ def add_img_class(html: str, classes: str = 'img-fluid'):
 
     return mark_safe(str(soup))
 
+@register.filter
+def remove_tags(html: str, tags_csv: str = "img,figure,picture,source,br") -> str:
+    """
+    tags_csv에 적은 태그만 제거/치환.
+    - br은 공백으로 치환(붙어버리는 것 방지)
+    - 그 외 태그는 통째로 제거
+    """
+    if not html:
+        return ""
+    soup = BeautifulSoup(html, "html.parser")
+    targets = [t.strip().lower() for t in tags_csv.split(",") if t.strip()]
+    for name in targets:
+        for tag in soup.find_all(name):
+            if name == "br":
+                tag.replace_with(" ")  # 또는 "\n"로 개행 유지
+            else:
+                tag.decompose()
+    return str(soup)
+
